@@ -11,7 +11,7 @@ pub use runner_results::*;
 use anyhow::{Context, Result};
 use log::*;
 use parse_deqp::{DeqpStatus, DeqpTestResult};
-use parse_piglit::PiglitTestResult;
+use parse_piglit::{piglit_sanitize_test_name, PiglitTestResult};
 use rand::rngs::StdRng;
 use rand::seq::SliceRandom;
 use rand::SeedableRng;
@@ -751,7 +751,8 @@ impl Deqp for PiglitCommand {
         );
 
         for subtest in &piglit_result.subtests {
-            let subtest_name = format!("{}@{}", test.name, subtest.name);
+            let subtest_name =
+                format!("{}@{}", test.name, piglit_sanitize_test_name(&subtest.name));
 
             if self.skip_test(&subtest_name) {
                 error!(
